@@ -178,6 +178,7 @@ class MySQL_Thread
 	unsigned long long curtime;
 	unsigned long long pre_poll_time;
 	unsigned long long last_maintenance_time;
+	unsigned long long last_move_to_idle_thread_time;
 	std::atomic<unsigned long long> atomic_curtime;
 	PtrArray *mysql_sessions;
 	PtrArray *mirror_queue_mysql_sessions;
@@ -347,6 +348,7 @@ struct p_th_gauge {
 		mysql_monitor_read_only_interval,
 		mysql_monitor_read_only_timeout,
 		mysql_monitor_writer_is_also_reader,
+		mysql_monitor_replication_lag_group_by_host,
 		mysql_monitor_replication_lag_interval,
 		mysql_monitor_replication_lag_timeout,
 		mysql_monitor_history,
@@ -433,6 +435,7 @@ class MySQL_Threads_Handler
 		//! ProxySQL session wait timeout. Unit: 'ms'.
 		bool monitor_wait_timeout;
 		bool monitor_writer_is_also_reader;
+		bool monitor_replication_lag_group_by_host;
 		//! How frequently a replication lag check is performed. Unit: 'ms'.
 		int monitor_replication_lag_interval;
 		//! Read only check timeout. Unit: 'ms'.
@@ -459,8 +462,8 @@ class MySQL_Threads_Handler
 		int ping_timeout_server;
 		int shun_on_failures;
 		int shun_recovery_time_sec;
+		int unshun_algorithm;
 		int query_retries_on_failure;
-		bool client_multi_statements;
 		bool connection_warming;
 		int client_host_cache_size;
 		int client_host_error_counts;
@@ -492,11 +495,12 @@ class MySQL_Threads_Handler
 		bool query_digests_no_digits;
 		bool query_digests_normalize_digest_text;
 		bool query_digests_track_hostname;
+		bool query_digests_keep_comment;
 		int query_digests_grouping_limit;
+		int query_digests_groups_grouping_limit;
 		bool default_reconnect;
 		bool have_compress;
 		bool have_ssl;
-		bool client_found_rows;
 		bool multiplexing;
 //		bool stmt_multiplexing;
 		bool log_unhealthy_connections;
@@ -532,6 +536,7 @@ class MySQL_Threads_Handler
 		int set_query_lock_on_hostgroup;
 		int reset_connection_algorithm;
 		int auto_increment_delay_multiplex;
+		int auto_increment_delay_multiplex_timeout_ms;
 		int long_query_time;
 		int hostgroup_manager_verbose;
 		int binlog_reader_connect_retry_msec;
@@ -540,7 +545,7 @@ class MySQL_Threads_Handler
 		char *add_ldap_user_comment;
 		char *default_tx_isolation;
 		char *default_session_track_gtids;
-		char *default_variables[SQL_NAME_LAST];
+		char *default_variables[SQL_NAME_LAST_LOW_WM];
 		char *firewall_whitelist_errormsg;
 #ifdef DEBUG
 		bool session_debug;
@@ -583,6 +588,9 @@ class MySQL_Threads_Handler
 		std::array<prometheus::Counter*, p_th_counter::__size> p_counter_array {};
 		std::array<prometheus::Gauge*, p_th_gauge::__size> p_gauge_array {};
 	} status_variables;
+
+	std::atomic<bool> bootstrapping_listeners;
+
 	/**
 	 * @brief Update the client host cache with the supplied 'client_sockaddr',
 	 *   and the supplied 'error' parameter specifying if there was a connection
