@@ -35,11 +35,18 @@ struct bio_st {
 
 typedef int CRYPTO_REF_COUNT;
 
-// in libssl 1.1.1
+/**
+ * @brief This is the 'bio_st' struct definition from libssl 3.0.0. NOTE: This is an internal struct from
+ *   OpenSSL library, currently it's used for performing checks on the reads/writes performed on the BIO objects.
+ *   It's extremely important to keep this struct up to date with each OpenSSL dependency update.
+ */
 struct bio_st {
+    OSSL_LIB_CTX *libctx;
     const BIO_METHOD *method;
     /* bio, mode, argp, argi, argl, ret */
+#ifndef OPENSSL_NO_DEPRECATED_3_0
     BIO_callback_fn callback;
+#endif
     BIO_callback_fn_ex callback_ex;
     char *cb_arg;               /* first argument for the callback */
     int init;
@@ -191,6 +198,9 @@ enum sslstatus MySQL_Data_Stream::do_ssl_handshake() {
 					}
 				}
 			}
+
+			sk_GENERAL_NAME_pop_free(alt_names, GENERAL_NAME_free);
+			X509_free(cert);
 		} else {
 			// we currently disable this annoying error
 			// in future we can configure this as per user level, specifying if the certificate is mandatory or not
@@ -896,9 +906,12 @@ int MySQL_Data_Stream::read_pkts() {
 int MySQL_Data_Stream::buffer2array() {
 	int ret=0;
 	bool fast_mode=sess->session_fast_forward;
-	if (queue_data(queueIN)==0) return ret;
-	if ((queueIN.pkt.size==0) && queue_data(queueIN)<sizeof(mysql_hdr)) {
-		queue_zero(queueIN);
+	{
+		unsigned long s = queue_data(queueIN);
+		if (s==0) return ret;
+		if ((queueIN.pkt.size==0) && s<sizeof(mysql_hdr)) {
+			queue_zero(queueIN);
+		}
 	}
 
 	if (fast_mode) {
